****************************************************************
* Program name:  rental_merge_p1.sas
* Project:       Housing Discrimination Study Phase II
*
*  Final version:  April 3, 2003 by Steve Ross
*
*  This program merges together the final sample of phase I rental 
*  tests with counts and means from the sample of rental units 
*  recommended or inspected by the testers, as well as information 
*  on whether follow-up contact was made by the real estate agent.  The 
*  resulting sample is used to create treatment variables for the
*  from phase I that can be combined with phase II data in order
*  to create state report cards and national Asian estimates.
*
* Input Files:   finrent.ssd01, follow.ssd01, q17nodup.ssd01
*
* Output Files:  fnrntmr2.ssd01
*                                            
****************************************************************;

options nocenter ;

libname hds2000 '/work/ross/phase1' ;
libname hdsp2 '/work/ross/phase2' ;


filename finrent '/work/ross/phase1/finrent.ssd01' ;
filename fnrntmr2 '/work/ross/phase2/fnrntmr2.ssd01' ;
filename follow '/work/ross/phase1/follow.ssd01' ;
filename q17nodup '/work/ross/phase1/q17nodup.ssd01' ;

/* load final sample of rental tests */

data tests ;
  set hds2000.finrent;

/* load sample with information on followup contacts */

data follow ;
  set hds2000.follow ;
  if totcnt2>0 then follow=1 ;
    else follow=0 ;
  keep control testerid follow ;

proc sort ;
  by control testerid ;

/* load final sample of rental units */

data unit ;
  set hds2000.q17nodup ;
  count=1 ;

  /* check if unit is available when testers need it */

  if ruavlbl3=2001 then ruavlbl3=1 ;
  if ruavlbl3=2000 then ruavlbl3=0 ;
  if ruavlbl1 in (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12) then
       ruavlbl1=ruavlbl1 ; else ruavlbl1=. ;
  if ruavlbl2 in (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 
                  11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 
                  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
                  31)  then
       ruavlbl2=ruavlbl2 ; else ruavlbl2=. ;

  if ruavlbl3<adate_y or adate_y=. or ruavlbl3=. then timeav=1 ;
    else  if ruavlbl3>adate_y then timeav=0 ;
    else if ruavlbl1<adate_m 
       or adate_m=. or ruavlbl1=. then timeav=1 ;
    else if ruavlbl1>adate_m then timeav=0 ;
    else if ruavlbl2<=adate_d or adate_d=. or ruavlbl2=.
        then timeav=1 ;
    else timeav=0 ; 


  /* check if unit meets size and price range requirements */  
  
  if abedreql<=rubed1<=abedrequ or rubed1=. or abedreql=. then meetbreq=1 ;
    else if rubed1 in (0.5, 1.5, 2.5, 3.5, 4.5, 5.5) then do ;
       if abedreql<=rubed1-0.5<=abedrequ or abedreql<=rubed1+0.5<=abedrequ  
           then meetbreq=1 ;
       else meetbreq=0 ;
       end ;
     else meetbreq=0 ;
  if rubed1+0.5>=abedmin then meetbmin=1 ;
    else if meetbreq=1 then meetbmin=1 ;
    else meetbmin=0 ;


  if rurent1<=apricehl or rurent1=. then meetprng=1 ;
    else meetprng=0 ;
  
  if rurent1<=apricehl or rurent1=. then meetprn2=1 ;
    else meetprn2=0 ;
  
  /* record if unit is advertised unit and whether inspected */

  if ruinad1=1 then advunit=1 ;
    else advunit=0 ;
  if ruinsp1=1 then inspect=1 ;
    else inspect=0 ;
  if inspect=1 and advunit=1 then inspadv=1 ;
    else inspadv=0 ;
  if advunit=1 and meetbreq=1 and timeav=1 and meetprng=1
     then advmeet=1 ; else advmeet=0 ;
  if advunit=1 and meetbreq=1 and timeav=1 and meetprn2=1
     then advmeet2=1 ; else advmeet2=0 ;
  if advunit=1 and meetbmin=1 and timeav=1 and meetprng=1
     and advmeet=0 then advacc=1 ; else advacc=0 ;
  if advunit=1 and meetbmin=1 and timeav=1 and meetprn2=1
     and advmeet2=0 then advacc2=1 ; else advacc2=0 ;

  /* record if similar unit and whether inspected where similar
  is defined as within the price range and has same number of
  bedrooms as the advertised unit */

  if meetbreq=1 and meetprng=1 and
        timeav=1 and advunit=0 then similar=1 ;
    else similar=0 ;
  if inspect=1 and similar=1 then inspsim=1 ;
    else inspsim=0 ;
  if meetbreq=1 and meetprn2=1 and
        timeav=1 and advunit=0 then similar2=1 ;
    else similar2=0 ;
  if inspect=1 and similar2=1 then inspsim2=1 ;
    else inspsim2=0 ;

  /* record if acceptable unit and whether inspected where
  acceptable is defined as less than maximum price specified
  and meets the minimum number of bedrooms required   */

  if meetbmin=1 and meetprng=1 and
        timeav=1 and advunit=0 and similar=0
        then accept=1 ;
    else accept=0 ;
  if inspect=1 and accept=1 then inspacc=1 ;
    else inspacc=0 ;
  if meetbmin=1 and meetprn2=1 and
        timeav=1 and advunit=0 and similar2=0 
        then accept2=1 ;
    else accept2=0 ;
  if inspect=1 and accept2=1 then inspacc2=1 ;
    else inspacc2=0 ;

  /* calculate rent, security deposit, and amenities for advertised units
  as well as whether specific utilities are provided */

  if advunit=1 then do ;
     advrent=rurent1 ;
     advisec=isecdep ;
     advnsec=nsecdep ;
     if ruelcin1=1 then advelec=1 ;
       else advelec=0 ;
     if rugasin1=1 then advgas=1 ;
        else advgas=0 ;
     if ruh2oin1=1 then advwater=1 ;
        else advwater=0 ;
     if ruhetin1=1 then advheat=1 ;
        else advheat=0  ;
     if rucolin1=1 then advair=1 ;
        else advair=0 ;
     end ;


  if similar=1 then do ;
     simrent=rurent1 ;
     simisec=isecdep ;
     simnsec=nsecdep ;
     if ruelcin1=1 then simelec=1 ;
       else simelec=0 ;
     if rugasin1=1 then simgas=1 ;
        else simgas=0 ;
     if ruh2oin1=1 then simwater=1 ;
        else simwater=0 ;
     if ruhetin1=1 then simheat=1 ;
        else simheat=0  ;
     if rucolin1=1 then simair=1 ;
        else simair=0 ;
    end ;


/* record geographic information for the advertised unit as well
  as for similar units */

  if advunit=1 then advmval=mval00 ;
       else advmval=. ;
  if advunit=1 then advpci=pci00 ;
        else advpci=. ;
  if advunit=1 then advpblk=pctblk ;
       else advpblk=. ;
  if advunit=1 then advphsp=pcthisp ;
         else advphsp=. ;
  if advunit=1 then advpown=pctownoc ;
         else advpown=. ;
  if advunit=1 then advpov=povrat90 ;
       else advpov=. ;




    if advunit^=1 then simmval=mval00 ;
       else simmval=. ;
    if advunit^=1 then simpci=pci00 ;
        else simpci=. ;
    if advunit^=1 then simpblk=pctblk ;
       else simpblk=. ;
    if advunit^=1 then simphsp=pcthisp ;
       else simphsp=. ;
    if advunit^=1 then simpown=pctownoc ;
       else simpown=. ;
    if advunit^=1 then simpov=povrat90 ;
       else simpov=. ;



/* create units level variables */

proc sort data=unit ;
  by control testerid ;


/* create average of unit characteristics by visit and by
  type of unit, e.g. advertised, similar, or acceptable unit  */

proc means noprint data=unit ;
  by control testerid ;
  var advmval advpci advpblk advphsp advpown advpov advrent
        simmval simpci simpblk simphsp simpown simpov simrent ;
  output out=mnunit mean=amval apci apblk aphsp apown apov arnt
       smval spci spblk sphsp spown spov srnt stderr=sdmval ;
  
/* create variables on numbers of units by visit by 
  type of unit, e.g. advertised, similar, or acceptable unit  */

proc means noprint data=unit ;
  by control testerid ;
  var count inspect advunit inspadv advmeet advmeet2 advacc advacc2
      similar similar2 inspsim inspsim2 accept accept2 inspacc inspacc2 ;
  output out=sumunit sum=number numinsp numadv advinsp advmtm advmtm2
    advaccm advaccm2 numsim numsim2 siminsp siminsp2 numacc numacc2
    accinsp accinsp2  ;

/* create variables on number of advertised units in test combining
  units across the two visits */

proc means noprint data=unit ;
  by control ;
  var advunit advmeet ;
  output out=munit2 sum=numadv2 advmtm2 ;

/* merge number of units information with units sample by visit */

data munit ;
  set sumunit ;
  keep control testerid numadv advmtm ;

data unit ;
  merge unit (in=q1) munit ;
  by control testerid ;
  if q1 ;

/* merge number of advertised units information with units sample
  by test */

data unit ;
  merge unit (in=q1) munit2 ;
  by control ;
  if q1 ;

/* create sample of advertised units for analysis
of rent and security deposit */

data advunit ;
  set unit ;
  count=1 ;
  if advrent=0 then advrent=. ;

/* only keep unit if it is the advertised unit, there is only
one advertised unit for this tester and two advertised units
for the pair.  Or keep if the same conditions met for an
advertised unit that meets the testers needs */ 

  if advunit=1 and numadv=1 and numadv2=2 then output advunit ;
    else if advmeet=1 and  advmtm=1 and advmtm2=2 then output advunit ;
    else delete ;
  keep control testerid advrent advisec advnsec advair advelec
     advheat advwater advgas ;

proc sort ;
  by control testerid ;


/* create minority variables for all unit samples.  The first sample
  mnunit contains the means for neighborhood variables over the set
  of advertised or similar units.  The second sample rental terms for 
  the sample of unique advertised units.  The third sample contains 
  the counts of different types of units. The fourth sample contains
  information on follow-up contact.  */

data munits0 ;
   set mnunit ;
   mtestid=testerid ;

       mamval=amval ; 
       mapci=apci ; 
       mapblk=apblk ; 
       maphsp=aphsp ;
       mapown=apown ; 
       mapov=apov ;
       marnt=arnt ;

       msmval=smval ; 
       mspci=spci ; 
       mspblk=spblk ; 
       msphsp=sphsp ;
       mspown=spown ; 
       mspov=spov ;
       msrnt=srnt ;

   keep control mtestid mamval mapci mapblk maphsp mapown mapov sdmval
             msmval mspci mspblk msphsp mspown mspov marnt msrnt ;

proc sort data=munits0   ;
  by control mtestid ;


data munits1 ;
   set advunit ;
   mtestid=testerid ;
   madvrent=advrent ;
   madvisec=advisec ;
   madvnsec=advnsec ;
   madvair=advair ;
   madvgas=advgas ;
   madvheat=advheat ;
   madvwatr=advwater ;
   madvelec=advelec ;
   keep control mtestid     madvrent    
     madvisec    madvnsec    madvair    madvgas    madvheat
     madvwatr    madvelec    ;

proc sort data=munits1   ;
  by control mtestid ;

data munits2 ;
   set sumunit ;
   mtestid=testerid ;
   mnuminsp=numinsp ;
   madvmtm=advmtm ;
   madvmtm2=advmtm2 ;
   madvacc=advaccm ;
   madvacc2=advaccm2 ;
   madvinsp=advinsp ;
   mnumacc=numacc ;
   mnumacc2=numacc2 ;
   mnumsim=numsim ;
   mnumsim2=numsim2 ;
   msiminsp=siminsp ;
   msimins2=siminsp2 ;
   keep control mtestid    mnuminsp    madvmtm    madvmtm2    
     madvacc    madvacc2    madvinsp    mnumacc    mnumacc2    
     mnumsim    mnumsim2    msiminsp    msimins2    ;

proc sort data=munits2   ;
  by control mtestid ;

data munits3 ;
   set follow ;
   mtestid=testerid ;
   mfollow=follow ;
   keep control mtestid mfollow ;

proc sort data=munits3   ;
  by control mtestid ;

proc sort data=tests   ;
  by control mtestid ;

/* merge in unit level variables by minority testerid */

data tests ;
  merge tests (in=q1) munits0 munits1 (in=q2) munits2 (in=q3) 
           munits3 (in=q4) ;
    by control mtestid ;
    if q1 ;

/* create majority variables for all units.  The first sample
  mnunit contains the means for neighborhood variables over the set
  of advertised or similar units.  The second sample rental terms for 
  the sample of unique advertised units.  The third sample contains 
  the counts of different types of units.  The fourth sample contains
  information on follow-up contact.  */


data wunits0 ;
   set mnunit ;
   wtestid=testerid ;


       wamval=amval ; 
       wapci=apci ; 
       wapblk=apblk ; 
       waphsp=aphsp ;
       wapown=apown ; 
       wapov=apov ;
       warnt=arnt ;

       wsmval=smval ; 
       wspci=spci ; 
       wspblk=spblk ; 
       wsphsp=sphsp ;
       wspown=spown ; 
       wspov=spov ;
       wsrnt=srnt ;


   keep control wtestid wamval wapci wapblk waphsp wapown wapov sdmval
              wsmval wspci wspblk wsphsp wspown wspov warnt wsrnt ;

proc sort data=wunits0   ;
  by control wtestid ;

data wunits1 ;
   set advunit ;
   wtestid=testerid ;
   wadvrent=advrent ;
   wadvisec=advisec ;
   wadvnsec=advnsec ;
   wadvair=advair ;
   wadvgas=advgas ;
   wadvheat=advheat ;
   wadvwatr=advwater ;
   wadvelec=advelec ;
   keep control wtestid    wadvrent    
     wadvisec    wadvnsec    wadvair    wadvgas    wadvheat
     wadvwatr    wadvelec  ;

proc sort data=wunits1   ;
  by control wtestid ;

data wunits2 ;
   set sumunit ;
   wtestid=testerid ;
   wnuminsp=numinsp ;
   wadvmtm=advmtm ;
   wadvmtm2=advmtm2 ;
   wadvacc=advaccm ;
   wadvacc2=advaccm2 ;
   wadvinsp=advinsp ;
   wnumacc=numacc ;
   wnumacc2=numacc2 ;
   wnumsim=numsim ;
   wnumsim2=numsim2 ;
   wsiminsp=siminsp ;
   wsimins2=siminsp2 ;
   keep control wtestid    wnuminsp    wadvmtm    wadvmtm2    
     wadvacc    wadvacc2    wadvinsp    wnumacc    wnumacc2    
     wnumsim    wnumsim2    wsiminsp    wsimins2  ;

proc sort data=wunits2   ;
  by control wtestid ;

data wunits3 ;
   set follow ;
   wtestid=testerid ;
   wfollow=follow ;
   keep control wtestid wfollow ;

proc sort data=wunits3   ;
  by control wtestid ;

proc sort data=tests   ;
  by control wtestid ;

/* merge in unit level variables by minority testerid */


data tests ;
  merge tests (in=q1) wunits0 wunits1 (in=q2) wunits2 (in=q3) 
          wunits3 (in=q4) ;
    by control wtestid ;
  if q1 ;

/* create treatment variables */

/* replace missing variables with zero for no treatment */ 

  if wnuminsp=. then wnuminsp=0 ;
  if wadvinsp=. then wadvinsp=0 ;
  if wsiminsp=. then wsiminsp=0 ;
  if wsimins2=. then wsimins2=0 ;
  if wadvmtm=. then wadvmtm=0 ;
  if wadvmtm2=. then wadvmtm2=0 ;
  if wadvacc=. then wadvacc=0 ;
  if wadvacc2=. then wadvacc2=0 ;
  if wnumsim=. then wnumsim=0 ;
  if wnumsim2=. then wnumsim2=0 ;
  if wnumacc=. then wnumacc=0 ;
  if wnumacc2=. then wnumacc2=0 ;
  if wfollow=. then wfollow=0 ;

  if mnuminsp=. then mnuminsp=0 ;
  if madvinsp=. then madvinsp=0 ;
  if msiminsp=. then msiminsp=0 ;
  if msimins2=. then msimins2=0 ;
  if madvmtm=. then madvmtm=0 ;
  if madvmtm2=. then madvmtm2=0 ;
  if madvacc=. then madvacc=0 ;
  if madvacc2=. then madvacc2=0 ;
  if mnumsim=. then mnumsim=0 ;
  if mnumsim2=. then mnumsim2=0 ;
  if mnumacc=. then mnumacc=0 ;
  if mnumacc2=. then mnumacc2=0 ;
  if mfollow=. then mfollow=0 ;


/* advertised unit available */

  if wavladv=1 then wavailad=1 ;
    else if wavladv=2 then wavailad=0 ;
    else if wadvmtm>0 then wavailad=1 ;
    else wavailad=0 ;
  wavaila2=wavailad ;
  if wadvmtm2>0 then wavaila2=1 ;

  if mavladv=1 then mavailad=1 ;
    else if mavladv=2 then mavailad=0 ;
    else if madvmtm>0 then mavailad=1 ;
    else mavailad=0 ;
  mavaila2=mavailad ;
  if madvmtm2>0 then mavaila2=1 ;

/* similar unit available */

  if wsamebed=1 then wavailsm=1 ;
    else if wsamebed=2 then wavailsm=0 ;
    else if wnumsim>0 then wavailsm=1 ;
      else wavailsm=0 ;
  wavails2=wavailsm ;
  if wnumsim2>0 then wavails2=1 ;
  

  if msamebed=1 then mavailsm=1 ;
    else if msamebed=2 then mavailsm=0 ;
    else if mnumsim>0 then mavailsm=1 ;
      else mavailsm=0 ;
  mavails2=mavailsm ;
  if mnumsim2>0 then mavails2=1 ;

/*  Advertised unit inspected */

   if wadvinsp=0 then winspadv=0 ;
     else winspadv=1 ;
   if madvinsp=0 then minspadv=0 ;
     else minspadv=1 ;

   if wadvinsp>0 and wadvmtm>0 then winspad1=1 ;
     else winspad1=0 ;
   if madvinsp>0 and madvmtm>0 then minspad1=1 ;
     else minspad1=0 ;

   if wadvinsp>0 and wadvmtm2>0 then winspad2=1 ;
     else winspad2=0 ;
   if madvinsp>0 and madvmtm2>0 then minspad2=1 ;
     else minspad2=0 ;


/*  Similar unit inspected */

   if wsiminsp=0 then winspsim=0 ;
     else winspsim=1 ;
   if wsimins2=0 then winspsi2=0 ;
     else winspsi2=1 ;

   if msiminsp=0 then minspsim=0 ;
     else minspsim=1 ;
   if msimins2=0 then minspsi2=0 ;
     else minspsi2=1 ;

/*  Number of units recommended */

   if wtotunit^=. then wrecom=wtotunit ;
     else wrecom=wadvmtm+wadvacc+wnumsim+wnumacc ;
   if wtotunit^=. then wrecom2=wtotunit ;
     else wrecom2=wadvmtm2+wadvacc2+wnumsim2+wnumacc2 ;

   if mtotunit^=. then mrecom=mtotunit ;
     else mrecom=madvmtm+madvacc+mnumsim+mnumacc ;
   if mtotunit^=. then mrecom2=mtotunit ;
     else mrecom2=madvmtm2+madvacc2+mnumsim2+mnumacc2 ;


  mrecomi=0 ;
  wrecomi=0 ;
  if mrecom>wrecom then mrecomi=1 ;
    else if mrecom<wrecom then wrecomi=1 ; 

  mrecomi2=0 ;
  wrecomi2=0 ;
  if mrecom2>wrecom2 then mrecomi2=1 ;
    else if mrecom2<wrecom2 then wrecomi2=1 ; 

/*  Number of units inspected */

  minspect=mnuminsp ;
  winspect=wnuminsp ;

  minspcti=0 ;
  winspcti=0 ;
  if minspect>winspect then minspcti=1 ;
    else if minspect<winspect then winspcti=1 ; 

/*  Agent asked about income */

   if wqincome=1 then waskinc=1 ;
       else waskinc=0 ;

   if mqincome=1 then maskinc=1 ;
       else maskinc=0 ;

/*  Agent qualified tester */

   if magqual=1 then mqual=1 ;
      else mqual=0 ;
   if wagqual=1 then wqual=1 ;
      else wqual=0 ;

/*  Invitation to complete applications */

   if winvtapp=1 then waskfill=1 ;
       else waskfill=0 ;

   if minvtapp=1 then maskfill=1 ;
       else maskfill=0 ;

/*  Tester asked to callback */

   if wfutcon2=1 then wcallbak=1 ;
       else wcallbak=0 ;

   if mfutcon2=1 then mcallbak=1 ;
       else mcallbak=0 ;


/*  No provision made for future contact */

   if wfutcon3=1 then wnofutcn=1 ;
       else wnofutcn=0 ;

   if mfutcon3=1 then mnofutcn=1 ;
       else mnofutcn=0 ;

/* credit check required */

  if wcredchk^=1 then wcredchk=0 ;
  if mcredchk^=1 then mcredchk=0 ;

/*  Told about waiting list */

  if wwait=2 or wwait=0 then wwaitlst=0 ;
    else  wwaitlst=1 ;

  if mwait=2 or mwait=0 then mwaitlst=0 ;
    else mwaitlst=1 ;


/*  Suggest different complex */

  if wsugdiff=1 then wsugdiff=1 ;
    else wsugdiff=0 ;

  if msugdiff=1 then msugdiff=1 ;
    else msugdiff=0 ;

/*  Was an application fee required */

   if wfeereq>0 and wfeereq^=. then wappfee=1 ;
     else wappfee=0 ;

   if mfeereq>0 and mfeereq^=. then mappfee=1 ;
     else mappfee=0 ;

  if wfeereq=. then wfeeamt=0 ;
    else wfeeamt=wfeereq ; 

  if mfeereq=. then mfeeamt=0 ;
    else mfeeamt=mfeereq ; 

mfeeamti=0 ;
wfeeamti=0 ;
if mfeeamt>wfeeamt then wfeeamti=1 ;
  else if mfeeamt<wfeeamt then mfeeamti=1 ;

/*  Any special incentives offered */

   if wincent=1 then wincent=1 ;
     else wincent=0 ;

   if mincent=1 then mincent=1 ;
     else mincent=0 ;

/*  Monthly rent */

   if wadvrent=0 then wrentad=. ;
     else wrentad=wadvrent ;

   if madvrent=0 then mrentad=. ;
     else mrentad=madvrent ;

  mrentadi=0 ;
  wrentadi=0 ;
  if mrentad>wrentad then mrentadi=1 ;
  if mrentad<wrentad then wrentadi=1 ; 
  if mrentad=. or wrentad=. then do ;
       mrentadi=. ;
       wrentadi=. ;
       mrentad=. ;
       wrentad=. ;
      end ;

/*  security deposit - note that the continuous/numeric information
  on security deposit in dollars is used before any information on the
  number of months of security deposit  */

   if wadvisec^=. and wadvrent^=. and wadvrent^=0 then 
       wsecdep=wadvisec*wadvrent ;
     else if wadvnsec^=. then wsecdep=wadvnsec ;  
     else wsecdep=. ;

   if madvisec^=. and madvrent^=. and madvrent^=0 then 
       msecdep=madvisec*madvrent ;
     else if madvnsec^=. then msecdep=madvnsec ;  
     else msecdep=. ;

   if msecdep=. or wsecdep=. then do ;
     msecdep=. ;
     wsecdep=. ;
     end ;

/*  create integer variable for whether white or minority is favored
  on security deposit.  If no difference, both treatment variables
  are set to zero. */

  msecdepi=0 ;
  wsecdepi=0 ;
  if madvisec>wadvisec and madvisec^=. and wadvisec^=. then msecdepi=1 ;
  else if madvisec<wadvisec and madvisec^=. and wadvisec^=. 
       then wsecdepi=1 ;
  else if madvisec^=. and wadvisec^=. then msecdepi=0 ;
  else if madvnsec>wadvnsec and madvnsec^=. and wadvnsec^=.
        then msecdepi=1 ;
  else if madvnsec<wadvnsec and madvnsec^=. and wadvnsec^=. 
       then wsecdepi=1 ;
  else if madvnsec^=. and wadvnsec^=. then msecdepi=0 ;
  else  do ;
       msecdepi=. ;
       wsecdepi=. ;
      end ;



/*  Interview time */

   if mbegt_am=2 and mbegt_h^=12 then mhourbg=mbegt_h+12 ;
     else if mbegt_am=1 then mhourbg=mbegt_h ;
     else mhourbg=. ;  
   if mendt_am=2 and mendt_h^=12 then mhournd=mendt_h+12 ;
     else if mendt_am=1 then mhournd=mendt_h ;
     else mhournd=. ;  
   mmeettim=mhournd*60 + mendt_m - (mhourbg*60 + mbegt_m) - mwaittim ;
   if mmeettim<0 then mmeettim=0 ;
   if mmeetag=2 then mmeettim=0 ;
   if mmeettim>=720 then mmeettim=mmeettim-720 ;
   if mmeettim>=300 then mmeettim=0 ;

   if wbegt_am=2 and wbegt_h^=12 then whourbg=wbegt_h+12 ;
     else if wbegt_am=1 then whourbg=wbegt_h ;
     else whourbg=. ;  
   if wendt_am=2 and wendt_h^=12 then whournd=wendt_h+12 ;
     else if wendt_am=1 then whournd=wendt_h ;
     else whournd=. ;  
   wmeettim=whournd*60 + wendt_m - (whourbg*60 + wbegt_m) - wwaittim ;
   if wmeettim<0 then wmeettim=0 ;
   if wmeetag=2 then wmeettim=0 ;
   if wmeettim>=720 then wmeettim=wmeettim-720 ;
   if wmeettim>=300 then wmeettim=. ;

/*  create binary indicators for favored on interview time with a
  5 minute threshold */

  wmeettmi=0 ;
  mmeettmi=0 ;
  if wmeettim>mmeettim+5 and wmeettim^=. and mmeettim^=.  then wmeettmi=1 ;
  if wmeettim+5<mmeettim and wmeettim^=. and mmeettim^=. then mmeettmi=1 ;


  if wmeettim=. or mmeettim=. then do ;
       wmeettmi=. ;
       mmeettmi=. ;
       wmeettim=. ;
       mmeettim=. ;
       end ;


  site=substr(control,1,2) ;
  type=substr(control,5,1) ;




/*  geography - Use location of white advertised unit unless missing.
  Progress first to minority advertised unit then to white similar
  unit ect.  Create a fill code variable to identify what information 
  was used to replace missing geographic information. */

if wamval=. and mamval=. and wsmval=. and msmval=. then do ;
   fillcod2='' ;
   mval=. ;
   pci=. ;
   pblk=. ;
   phsp=. ;
   pown=. ;
   pov=. ;
   end ;
else if wamval=. and mamval=. and wsmval=. then do ;
   fillcod2='11' ;
   mval=msmval ;
   pci=mspci ;
   pblk=mspblk ;
   phsp=msphsp ;
   pown=mspown ;
   pov=mspov ;
   end ;
else if wamval=. and mamval=. then do ;
   fillcod2='01' ;
   geoflmid=0 ;
   geoflsim=1 ;
   mval=wsmval ;
   pci=wspci ;
   pblk=wspblk ;
   phsp=wsphsp ;
   pown=wspown ;
   pov=wspov ;
   end ;
else if wamval=. then do ;
   fillcod2='10' ;
   geoflmid=0 ;
   geoflsim=0 ;
   mval=mamval ;
   pci=mapci ;
   pblk=mapblk ;
   phsp=maphsp ;
   pown=mapown ;
   pov=mapov ;
   end ;
else if wamval^=. then do ;
   fillcod2='00' ;
   geoflmid=0 ;
   geoflsim=0 ;
   mval=wamval ;
   pci=wapci ;
   pblk=wapblk ;
   phsp=waphsp ;
   pown=wapown ;
   pov=wapov ;
   end ;


/* Create racial composition variable based on ethnicity of the
  test */

if type='B' then prce=pblk ;
  else if type='H' then prce=phsp ;
  else prce=. ;

/* site labels */

  if site='AT' then do ;
    sitename='Atlanta' ;
    sitecode=520 ; 
    end ; 
  if site='AU' then do ;
    sitename='Austin' ;
    sitecode=640 ; 
    end ; 
  if site='PX' then do ;
    sitename='Phoenix' ;
    sitecode=6200 ; 
    end ; 
  if site='BR' then do ;
    sitename='Birmingham' ;
    sitecode=1000 ; 
    end ; 
  if site='CH' then do ;
    sitename='Chicago' ;
    sitecode=1600 ; 
    end ; 
  if site='DC' then do ;
    sitename='Washington, D.' ;
    sitecode=8840 ; 
    end ; 
  if site='DN' then do ;
    sitename='Denver' ;
    sitecode=2080 ; 
    end ; 
  if site='DS' then do ;
    sitename='Dayton' ;
    sitecode=2000 ; 
    end ; 
  if site='DT' then do ;
    sitename='Detroit' ;
    sitecode=2160 ; 
    end ; 
  if site='HO' then do ;
    sitename='Houston' ;
    sitecode=3360 ; 
    end ; 
  if site='LA' then do ;
    sitename='Los Angeles' ;
    sitecode=4480 ; 
    end ; 
  if site='MA' then do ;
    sitename='Macon' ;
    sitecode=4680 ; 
    end ; 
  if site='NY' then do ;
    sitename='New York' ;
    sitecode=5600 ; 
    end ; 
  if site='NO' then do ;
    sitename='New Orleans' ;
    sitecode=5560 ; 
    end ; 
  if site='OR' then do ;
    sitename='Orlando' ;
    sitecode=5960 ; 
    end ; 
  if site='PH' then do ;
    sitename='Philadelphia' ;
    sitecode=6160 ; 
    end ; 
  if site='PT' then do ;
    sitename='Pittsburgh' ;
    sitecode=6280 ; 
    end ; 
  if site='PU' then do ;
    sitename='Pueblo' ;
    sitecode=6560 ; 
    end ; 
  if site='SA' then do ;
    sitename='San Antonio' ;
    sitecode=7240 ; 
    end ; 
  if site='SD' then do ;
    sitename='San Diego' ;
    sitecode=7320 ; 
    end ; 
  if site='TC' then do ;
    sitename='Tuscon' ;
    sitecode=8520 ; 
    end ; 


  year='2000' ;
  count=1 ;

  nsite=site ;
  if type='B' then ngroup='1' ;
  if type='H' then ngroup='2' ;
  if type='S' then do ;
    ngroup='3' ;
    nsite='MS' ;
    end ;
  if type='N' then ngroup='4' ;
  if type='C' then do ;
    ngroup='3' ;
    nsite='LC' ;        
    end ;
  if type='K' then do ;
    ngroup='3' ;
    nsite='LK' ;        
    end ;


keep control ngroup nsite type  
  count control mtestid wtestid
  wavailad mavailad wavailsm mavailsm winspadv minspadv winspad1
  wavaila2 mavaila2 wavails2 mavails2 winspad2 minspad2 minspad1
  winspsim minspsim winspect minspect wrecom mrecom 
  winspsi2 minspsi2 wrecom2 mrecom2 wrecomi2 mrecomi2 
  winspcti minspcti wrecomi mrecomi 
  waskfill maskfill  wcallbak mcallbak wmeettim mmeettim 
  wmeettmi mmeettmi wsugdiff msugdiff wwaitlst mwaitlst
  wnofutcn mnofutcn wfollow mfollow wqual mqual
  wrentad mrentad wsecdep msecdep wrentadi mrentadi 
  wsecdepi msecdepi wappfee mappfee wincent mincent 
  wadvelec madvelec wadvgas madvgas wadvheat madvheat
  wadvair madvair wadvwatr madvwatr mwait wwait
  samestr samebldg sameunit mrenta2i wrenta2i msecde2i
  wsecde2i sameagnt wcuremp mcuremp wemplngt memplngt 
  wstudnt mstudnt whighedu mhighedu wpegai wpegai
  whhegai mhhegai wcurtenr mcurtenr wmortfin mmortfin
  wexpernc mexpernc wtimecur mtimecur wtsex mtsex order
  whhrel1 whhrel2 whhrel3 whhrel4 whhrel5
  mhhrel1 mhhrel2 mhhrel3 mhhrel4 mhhrel5
  wmarried mmarried wchild mchild wpricell mpricell
  wpricehl mpricehl wlength mlength wvdate_m wvdate_d
  wvdate_y mvdate_m mvdate_d mvdate_y 
  wbegt_h wbegt_m wbegt_am mbegt_h mbegt_m mbegt_am 
  wbedreq mbedreq wbedmin mbedmin wsex msex 
  mval pci pblk phsp pown pov order prce fillcod2 
  wincome wincom2 mincome mincom2 wage mage warnt marnt
  wsrnt msrnt wfeeamt mfeeamt wfeeamti mfeeamti 
  wcredchk mcredchk maccent waccent mrank wrank ;


proc freq ;
  tables    maccent mrank nsite*ngroup order
           wcredchk*mcredchk 
           wappfee*mappfee 
           wavailad*mavailad 
           wavaila2*mavaila2 
           wavailsm*mavailsm 
           wavails2*mavails2 
           winspadv*minspadv 
           winspad1*minspad1
           winspad2*minspad2 
           winspsim*minspsim 
           winspsi2*minspsi2 
           wrecomi*mrecomi 
           wrecomi2*mrecomi2 
           winspcti*minspcti 
           waskfill*maskfill 
           wcallbak*mcallbak 
           wmeettmi*mmeettmi 
           wsugdiff*msugdiff 
           wwaitlst*mwaitlst
           wwait*wwaitlst
           mwait*mwaitlst
           wnofutcn*mnofutcn 
           wfollow*mfollow 
           wqual*mqual
           wrentadi*mrentadi 
           wsecdepi*msecdepi 
           wincent*mincent 
           wadvelec*madvelec 
           wadvgas*madvgas 
           wadvheat*madvheat
           wadvair*madvair 
           wadvwatr*madvwatr fillcod2 ;


/* save results to a permenant sas data set */

data hdsp2.fnrntmr2 ;
  set tests ; 




run;















